@@ -14,7 +14,9 @@ import aws_cdk.aws_servicediscovery._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-appmesh", "1.49.0", __name__[0:-6], "aws-appmesh@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-appmesh", "1.50.0", __name__[0:-6], "aws-appmesh@1.50.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
